.. highlight:: shell

============
Installation
============

Prerequisites
-------------

You will need `Apache Spark`_ available on your system. PySpark will be
installed when you install dye_score.


Stable release
--------------

To install Dye Score, run this command in your terminal:

.. code-block:: console

    $ pip install dye_score

From sources
------------

The sources for Dye Score can be downloaded from the `Github repo`_.

You can either clone the public repository:

.. code-block:: console

    $ git clone git://github.com/mozilla/dye_score

Or download the `tarball`_:

.. code-block:: console

    $ curl  -OL https://github.com/mozilla/dye_score/tarball/master

Once you have a copy of the source, you can install it with:

.. code-block:: console

    $ python setup.py install


.. _Apache spark: https://spark.apache.org/downloads.html
.. _Github repo: https://github.com/mozilla/dye_score
.. _tarball: https://github.com/mozilla/dye_score/tarball/master
